@@ -32,6 +32,12 @@ try:
 except ImportError:
     pass
 
+try:
+    # Mac OS, Python <3 only.
+    import MacOS
+except ImportError:
+    pass
+
 try:
     from uptime._posix import _uptime_posix
 except ImportError:
@@ -153,6 +159,28 @@ def _uptime_bsd():
         up = None
     return up
 
+def _uptime_mac():
+    """Returns uptime in seconds or None, on Mac OS."""
+    try:
+        # Python docs say a clock tick is 1/60th of a second, Mac OS docs say
+        # it's ``approximately'' 1/60th. It's incremented by vertical retraces,
+        # which the Macintosh Plus docs say happen 60.15 times per second.
+        # I don't know if ``approximately'' means it's actually 1/60.15, or
+        # 1/60 on some machines and 1/60.15 on others.
+        return MacOS.GetTicks() / 60.15
+    except:
+        return None
+
+def _uptime_minix():
+    """Returns uptime in seconds or None, on MINIX."""
+    try:
+        f = open('/proc/uptime', 'r')
+        up = float(f.read())
+        f.close()
+        return up
+    except (IOError, ValueError):
+        return None
+
 _uptime_osx = _uptime_bsd
 
 def _uptime_plan9():
@@ -251,8 +279,10 @@ def _uptime_solaris():
 
 def _uptime_syllable():
     """Returns uptime in seconds or None, on Syllable."""
+    global __boottime
     try:
-        return time.time() - os.stat('/dev/pty/mst/pty0').st_mtime
+        __boottime = os.stat('/dev/pty/mst/pty0').st_mtime
+        return time.time() - __boottime
     except:
         return None
 
@@ -294,7 +324,8 @@ def uptime():
             'linux': _uptime_linux,
             'linux-armv71': _uptime_linux,
             'linux2': _uptime_linux,
-            'minix3': _uptime_linux,
+            'mac': _uptime_mac,
+            'minix3': _uptime_minix,
             'riscos': _uptime_riscos,
             'sunos5': _uptime_solaris,
             'syllable': _uptime_syllable,
@@ -303,7 +334,7 @@ def uptime():
            _uptime_bsd() or _uptime_plan9() or _uptime_linux() or \
            _uptime_windows() or _uptime_solaris() or _uptime_beos() or \
            _uptime_amiga() or _uptime_riscos() or _uptime_posix() or \
-           _uptime_syllable()
+           _uptime_syllable() or _uptime_mac()
 
 def boottime():
     """Returns boot time if remotely possible, or None if not."""
